@@ -104,6 +104,13 @@ typedef enum _CmpackOpenMode
 	CMPACK_OPEN_CREATE		/**< Create a new file */
 } CmpackOpenMode;
 
+typedef enum _CmpackOpenFlags
+{
+	CMPACK_OPENF_RESERVED1 = (1 << 0),
+	CMPACK_OPENF_RESERVED2 = (1 << 1),
+	CMPACK_OPENF_POSITIVE_WEST = (1 << 2)
+} CmpackOpenFlags;
+
 /** \brief Load flags */
 typedef enum _CmpackLoadFlags
 {
@@ -613,13 +620,28 @@ CMPACK_EXPORT(int, cmpack_strtolat, (const char* buf, double* lat));
 
 /**
 	\brief Converts string to longitude.
-	\details The function converts nul-terminated string to longitude
+	\details The function converts nul-terminated string to longitude. Positive values are interpreted as longitudes east
+			 of the prime meridian and negative values are west.
 	\param[in] buf			input string
 	\param[out] lon			longitude in degrees (-180..180)
 	\return zero on success or error code on failure.
 */
 CMPACK_EXPORT(int, cmpack_strtolon, (const char* buf, double* lon));
 
+/**
+	\brief Converts string to longitude.
+	\details The function converts nul-terminated string to longitude. If the positiveWest
+	         parameter is set to zero, positive values are interpreted as longitudes east
+			 of the prime meridian and negative values are west. If the positiveWest parameter
+			 is set to non-zero, positive values are interpreted as longitudes west
+			 of the prime meridian and negative values are east. 
+	\param[in] buf			input string
+	\param[in] positiveWest true = positive value --> West, false = positive value --> East
+	\param[out] lon			longitude in degrees (-180..180)
+	\return zero on success or error code on failure.
+*/
+CMPACK_EXPORT(int, cmpack_strtolon2, (const char* buf, int positiveWest, double* lon));
+
 /**
 	\brief Converts the latitude to the string
 	\details The function prints longitude to memory buffer
