@@ -52,7 +52,7 @@ typedef struct _CmpackCcdFmt
 {
 	CmpackFormat format;									/**< Format identifier */
 	int (*test)(const char *, size_t, size_t);				/**< Test image format */
-	int (*open)(tHandle*, const char*, CmpackOpenMode);		/**< Open a file */
+	int (*open)(tHandle*, const char*, CmpackOpenMode, unsigned);		/**< Open a file */
 	tHandle (*init)(void);									/**< Create a new file */
 	void (*close)(tHandle);									/**< Close a file */
 	char* (*get_magic)(tHandle);							/**< Get magic string */
@@ -82,6 +82,10 @@ typedef struct _CmpackCcdFmt
 	int (*get_bool)(tHandle, const char*, int*);			/**< Get a logic value */
 	int (*get_param)(tHandle, int, char**, char**, char**);	/**< Parameter enumeration */
 	int (*copy_header)(tHandle, CmpackImageHeader*, CmpackChannel, CmpackConsole*);	/**< Save header to FITS file */
+	int (*strtora)(tHandle, const char*, double*);                   /**< String to R.A. conversion */
+	int (*strtodec)(tHandle, const char*, double*);                   /**< String to Dec. conversion */
+	int (*strtolon)(tHandle, const char*, double*);                   /**< String to longitude conversion */
+	int (*strtolat)(tHandle, const char*, double*);                   /**< String to laitude conversion */
 	int (*set_datetime)(tHandle, const CmpackDateTime*);	/**< Set date of observation */
 	void (*set_exptime)(tHandle, double);					/**< Set exposure duration */
 	void (*set_ccdtemp)(tHandle, double);					/**< Set CCD temperature */
@@ -103,8 +107,8 @@ static const CmpackCcdFmt flist[] = {
 		fits_getexptime, fits_getccdtemp, fits_getfilter, fits_getobject, 
 		fits_getobjra, fits_getobjdec, fits_getobserver, fits_getobservatory, fits_gettelescope, fits_getinstrument,
 		fits_getobslon, fits_getobslat, fits_getframes, fits_getwcs, fits_gkys, fits_gkyi, 
-		fits_gkyd, fits_gkyl, fits_gkyn, fits_copyheader, fits_setdatetime, 
-		fits_setexptime, fits_setccdtemp, fits_setframes, fits_setobject, fits_pkys, 
+		fits_gkyd, fits_gkyl, fits_gkyn, fits_copyheader, NULL, NULL, fits_strtolon, NULL,
+		fits_setdatetime, fits_setexptime, fits_setccdtemp, fits_setframes, fits_setobject, fits_pkys, 
 		fits_pkyi, fits_pkyd, fits_pkyl, fits_puthistory, fits_prepare, fits_putimage,
 		fits_restoreheader },
 	{ CMPACK_FORMAT_SBIG, sbig_test, sbig_open, NULL, sbig_close, sbig_getmagic, 
@@ -338,7 +342,7 @@ int cmpack_ccd_open(CmpackCcdFile **fc, const char *filename, CmpackOpenMode mod
 
 	/* Create context */
 	fs = file_create();
-	res = format->open(&fs->handle, filename, mode);
+	res = format->open(&fs->handle, filename, mode, flags);
 	if (res!=0) {
 		cmpack_ccd_destroy(fs);
 		return res;
@@ -740,12 +744,18 @@ int cmpack_ccd_get_params(CmpackCcdFile *fs, unsigned mask, CmpackCcdParams *par
 			}
 			if (fs->fmt->get_objra) {
 				char *ra = fs->fmt->get_objra(fs->handle);
-				fs->obj.ra_valid = cmpack_strtora(ra, &fs->obj.ra)==0;
+				if (fs->fmt->strtora)
+					fs->obj.ra_valid = fs->fmt->strtora(fs->handle, ra, &fs->obj.ra);
+				else
+					fs->obj.ra_valid = cmpack_strtora(ra, &fs->obj.ra) == 0;
 				cmpack_free(ra);
 			}
 			if (fs->fmt->get_objdec) {
 				char *dec = fs->fmt->get_objdec(fs->handle);
-				fs->obj.dec_valid = cmpack_strtodec(dec, &fs->obj.dec)==0;
+				if (fs->fmt->strtodec)
+					fs->obj.dec_valid = fs->fmt->strtodec(fs->handle, dec, &fs->obj.dec);
+				else
+					fs->obj.dec_valid = cmpack_strtodec(dec, &fs->obj.dec) == 0;
 				cmpack_free(dec);
 			}
 			fs->cache_flags |= CACHE_OBJECT;
@@ -760,12 +770,18 @@ int cmpack_ccd_get_params(CmpackCcdFile *fs, unsigned mask, CmpackCcdParams *par
 			}
 			if (fs->fmt->get_obslon) {
 				char *lon = fs->fmt->get_obslon(fs->handle);
-				fs->loc.lon_valid = cmpack_strtolon(lon, &fs->loc.lon)==0;
+				if (fs->fmt->strtolon)
+					fs->loc.lon_valid = fs->fmt->strtolon(fs->handle, lon, &fs->loc.lon);
+				else
+					fs->loc.lon_valid = cmpack_strtolon2(lon, 0, &fs->loc.lon) == 0;
 				cmpack_free(lon);
 			}
 			if (fs->fmt->get_obslat) {
 				char *lat = fs->fmt->get_obslat(fs->handle);
-				fs->loc.lat_valid = cmpack_strtolat(lat, &fs->loc.lat)==0;
+				if (fs->fmt->strtolat)
+					fs->loc.lat_valid = fs->fmt->strtolat(fs->handle, lat, &fs->loc.lat);
+				else
+					fs->loc.lat_valid = cmpack_strtolat(lat, &fs->loc.lat) == 0;
 				cmpack_free(lat);
 			}
 			fs->cache_flags |= CACHE_LOCATION;
