@@ -328,8 +328,10 @@ static int file_loadsrt(CmpackPhtFile *pht, FILE *f)
 		end += (int)strcspn(line1+end, " \t\r\n");
 		line1[end] = line2[end] = '\0';
 		key[0] = value[0] = '\0';
-		sscanf(line1+start, " %80[^ \t\r\n]", key);
-		sscanf(line2+start, " %80[^ \t\r\n]", value);
+		if (sscanf(line1+start, " %80[^ \t\r\n]", key) != 1)
+			key[0] = '\0';
+		if (sscanf(line2+start, " %80[^ \t\r\n]", value) != 1)
+			value[0] = '\0';
 		if (strcmp(key, "NX")==0)
 			pht->hd.width = atoi(value);
 		else if (strcmp(key, "NY")==0)
@@ -1056,6 +1058,7 @@ static int file_writebin(CmpackPhtFile *f, FILE *to)
 		return CMPACK_ERR_WRITE_ERROR;
 
 	/* Read and parse the header */
+	memset(hdr, 0, MAX_HEADER_SIZE * sizeof(char));
 	*(int32_t*)(hdr+4) = f->hd.width;
 	*(int32_t*)(hdr+8) = f->hd.height;
 	memcpy(hdr+12, &f->hd.jd, sizeof(double));
