@@ -268,7 +268,7 @@ static gint CompareByTime(const CFrameInfo *a, const CFrameInfo *b)
 // Constructor
 //
 CAddFilterDlg::CAddFilterDlg(GtkWindow *pParent, int context_id):m_Pages(NULL), m_Frames(NULL), 
-	m_ContextId(context_id)
+	m_ContextId(context_id), m_FirstPage(0), m_Recursive(false), m_DirPath(NULL), m_SrcFiles(NULL)
 {
 	m_pDlg = gtk_dialog_new_with_buttons("Add files", pParent, 
 		(GtkDialogFlags)(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
@@ -385,7 +385,7 @@ int CAddFilterDlg::PrepareFilesProc(CProgressDlg *sender, void *user_data)
 		sender->Print(basename);
 		g_free(basename);
 		if (!g_Project->FileInProject(filepath)) {
-			if (info.Init(filepath))
+			if (info.Init(filepath, g_Project->Profile()))
 				list = g_list_prepend(list, new CFrameInfo(info));
 		}
 		if (sender->Cancelled()) {
@@ -430,7 +430,7 @@ GList *CAddFilterDlg::ScanDir(CProgressDlg *sender, GList *list, const char *dir
 			filepath = g_build_filename(dirpath, filename, NULL);
 			if (g_file_test(filepath, G_FILE_TEST_IS_REGULAR)) {
 				if (!g_Project->FileInProject(filepath)) {
-					if (info.Init(filepath))
+					if (info.Init(filepath, g_Project->Profile()))
 						list = g_list_prepend(list, new CFrameInfo(info));
 				}
 			}
