@@ -327,7 +327,7 @@ bool CAMassCurveDlg::UpdateAirMassCurve(GtkWindow *parent)
 	m_MeasBox.SetTable(NULL);
 	delete m_Table;
 
-	m_Table = CmpackAirMassCurve(NULL, m_FrameSet, m_ObjCoords, m_Location, &error);
+	m_Table = CmpackAirMassCurve(NULL, m_FrameSet, *g_Project->Profile(), m_ObjCoords, m_Location, &error);
 	if (!m_Table) {
 		if (error) {
 			ShowError(parent, error->message, true);
@@ -1352,7 +1352,7 @@ bool CMakeAMassCurveDlg::OnCloseQuery()
 		ShowError(GTK_WINDOW(m_pDlg), "Please, enter the geographic coordinates.");
 		return false;
 	}
-	if (cmpack_strtolon(lon, &x)!=0) {
+	if (cmpack_strtolon2(lon, (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0), &x) != 0) {
 		ShowError(GTK_WINDOW(m_pDlg), "Invalid value of the longitude.");
 		return false;
 	}
@@ -1645,7 +1645,7 @@ bool CAMassCurveOptionsDlg::OnCloseQuery()
 		ShowError(GTK_WINDOW(m_pDlg), "Please, enter the geographic coordinates.");
 		return false;
 	}
-	if (cmpack_strtolon(lon, &x)!=0) {
+	if (cmpack_strtolon2(lon, (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0), &x) != 0) {
 		ShowError(GTK_WINDOW(m_pDlg), "Invalid value of the longitude.");
 		return false;
 	}
