@@ -328,7 +328,7 @@ bool CEditSelectionsDlg::Execute()
 					UpdateChart();
 					fts_file = g_Project->GetImageFile(refpath);
 					if (fts_file) {
-						m_Image = CImage::fromFile(fts_file, CMPACK_BITPIX_AUTO, &error);
+						m_Image = CImage::fromFile(fts_file, g_Project->Profile(), CMPACK_BITPIX_AUTO, &error);
 						UpdateImage();
 						g_free(fts_file);
 					}
@@ -357,7 +357,7 @@ bool CEditSelectionsDlg::Execute()
 				UpdateChart();
 				fts_file = SetFileExtension(tmp_file, FILE_EXTENSION_FITS);
 				if (fts_file) {
-					m_Image = CImage::fromFile(fts_file, CMPACK_BITPIX_AUTO, &error);
+					m_Image = CImage::fromFile(fts_file, g_Project->Profile(), CMPACK_BITPIX_AUTO, &error);
 					UpdateImage();
 					g_free(fts_file);
 				}
