@@ -521,6 +521,13 @@ void CAavsoExportDlg::ExportTable(CCSVWriter &f, CTable &table)
 		}
 	}
 
+	if (jd_prec > 7)
+		jd_prec = 7;
+	if (mag_prec > 4)
+		mag_prec = 4;
+	if (amass_prec > 4)
+		amass_prec = 4;
+
 	// Table data
 	if (m_ncomp==1) {
 		// Observation with single comparison star
@@ -553,7 +560,7 @@ void CAavsoExportDlg::ExportTable(CCSVWriter &f, CTable &table)
 					// Standard photometry: Instrumental magnitude of the check star!!!
 					f.SetDbl(10, kmag_value, mag_prec);
 				}
-				if (airmass > 0)
+				if (airmass > 0 && airmass < 99.0)
 					f.SetDbl(11, airmass, amass_prec);
 				if (m_params.chart && *m_params.chart!='\0')
 					f.SetStr(13, m_params.chart);
@@ -591,7 +598,7 @@ void CAavsoExportDlg::ExportTable(CCSVWriter &f, CTable &table)
 				f.SetStr(9, m_params.kname);
 				// Ensemble photometry: Standardized magnitude of the check star!!!
 				f.SetDbl(10, kmag_value - cmag_value + mag_offset, mag_prec);	
-				if (airmass > 0)
+				if (airmass > 0 && airmass < 99.0)
 					f.SetDbl(11, airmass, amass_prec);
 				if (m_params.chart && *m_params.chart!='\0')
 					f.SetStr(13, m_params.chart);
