@@ -38,13 +38,17 @@ enum tPageId
 	PAGE_NOTIFICATIONS,
 	PAGE_FILES_AND_DIRECTORIES,
 	PAGE_PERFORMANCE,
+	PAGE_PROJECT_DEFAULTS,
 	PAGE_DEBUGGING
 };
 
-static const struct tColumnDef {
-	const char *caption;
+struct tColumnDef
+{
+	const char* caption;
 	int bitmask;
-} Columns[] = {
+};
+
+static const tColumnDef Columns[] = {
 	{ "Date and time (UTC)",1 << 0 },
 	{ "Julian date",		1 << 1 },
 	{ "Exposure",			1 << 2 },
@@ -57,6 +61,19 @@ static const struct tColumnDef {
 	{ NULL }
 };
 
+struct tStringList
+{
+	const char* str;			// Caption (NULL = terminator)
+	int id;						// Value, bitmask
+};
+
+// Longitude direction
+static const tStringList LongitudeStrings[] = {
+	{ "East of Greenwich meridian",	0 },
+	{ "West of Greenwich meridian",	1 },
+	{ NULL }
+};
+
 struct tColumnData {
 	GtkWidget *btn;
 	const tColumnDef *info;
@@ -96,6 +113,14 @@ struct tDirData {
 	const tDirInfo *info;
 };
 
+static GtkWidget* add_label_plain(GtkWidget* vbox, const gchar* text)
+{
+	GtkWidget* label = gtk_label_new(text);
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
+	return label;
+}
+
 static GtkWidget *add_label_with_markup(GtkWidget *vbox, const gchar *text)
 {
 	GtkWidget *label = gtk_label_new(NULL);
@@ -114,6 +139,28 @@ static GtkWidget *add_check_button(GtkWidget *vbox, const gchar *text,
 	return btn;
 }
 
+static GtkWidget* add_combo_box(GtkWidget* vbox, const gchar* caption, const tStringList* strings, const gchar* tooltip)
+{
+	GtkWidget* cbox = gtk_combo_box_new_text();
+	for (int i = 0; strings[i].str != NULL; i++)
+		gtk_combo_box_append_text(GTK_COMBO_BOX(cbox), strings[i].str);
+	gtk_widget_set_tooltip_text(cbox, tooltip);
+
+	if (caption) {
+		GtkWidget* tbox2 = gtk_table_new(1, 2, FALSE);
+		gtk_table_set_col_spacings(GTK_TABLE(tbox2), 8);
+		gtk_box_pack_start(GTK_BOX(vbox), tbox2, FALSE, TRUE, 0);
+		GtkWidget* label = gtk_label_new(caption);
+		gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+		gtk_table_attach(GTK_TABLE(tbox2), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_table_attach(GTK_TABLE(tbox2), cbox, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+	}
+	else {
+		gtk_box_pack_start(GTK_BOX(vbox), cbox, FALSE, TRUE, 0);
+	}
+	return cbox;
+}
+
 static gchar *GetDefaultDir(int param_id)
 {
 	switch (param_id)
@@ -213,19 +260,19 @@ CPreferencesDlg::CPreferencesDlg(GtkWindow *pParent):m_CurrentPage(NULL), m_Colu
 		gtk_table_attach_defaults(GTK_TABLE(tbox), data->btn, i%2, (i%2)+1, i/2, (i/2)+1);
 		m_Columns = g_slist_prepend(m_Columns, data);
 	}
-	add_label_with_markup(vbox, "<b>Winows and dialogs:</b>");
+	add_label_with_markup(vbox, "<b>Windows and dialogs:</b>");
 	m_NoMaximize = add_check_button(vbox, "Do not maximize windows", "Do not maximize the windows when they show up.");
 
 	// Notification
 	vbox = CreatePage(PAGE_NOTIFICATIONS, "Notifications", "notifications", TRUE);
 	m_SoundFinished = add_check_button(vbox, "Play sound when a process has been finished", NULL);
 	if (!SoundIsSupported()) 
-		add_label_with_markup(vbox, "The program was compiled without sound support");
+		add_label_plain(vbox, "The program was compiled without sound support");
 	
 	// Files and directories
 	vbox = CreatePage(PAGE_FILES_AND_DIRECTORIES, "Files and directories", "files", TRUE);
 	add_label_with_markup(vbox, "<b>Use the following catalogues to look up the object coordinates:</b>");
-	add_label_with_markup(vbox, "Check the item and fill in the path to the catalog files.");
+	add_label_plain(vbox, "Check the item and fill in the path to the catalog files.");
 	tbox = gtk_table_new(0, 3, FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(tbox), 0);
 	gtk_table_set_col_spacing(GTK_TABLE(tbox), 0, 24);
@@ -247,7 +294,7 @@ CPreferencesDlg::CPreferencesDlg(GtkWindow *pParent):m_CurrentPage(NULL), m_Colu
 		m_Catalogs = g_slist_prepend(m_Catalogs, data);
 	}
 	add_label_with_markup(vbox, "<b>Use the following direcotories:</b>");
-	add_label_with_markup(vbox, "Check the item and specify your own path to the directory.");
+	add_label_plain(vbox, "Check the item and specify your own path to the directory.");
 	tbox = gtk_table_new(0, 3, FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(tbox), 0);
 	gtk_table_set_col_spacing(GTK_TABLE(tbox), 0, 24);
@@ -273,6 +320,13 @@ CPreferencesDlg::CPreferencesDlg(GtkWindow *pParent):m_CurrentPage(NULL), m_Colu
 	vbox = CreatePage(PAGE_PERFORMANCE, "Performance", "performance", TRUE);
 	m_NoPreviews = add_check_button(vbox, "Do not show previews in \"Open file\" dialogs", NULL);
 
+	// Project defaults
+	vbox = CreatePage(PAGE_PROJECT_DEFAULTS, "Project defaults", "preferences", TRUE);
+	add_label_plain(vbox, "Note: Changes of settings in this section do not affect existing projects!");
+	add_label_with_markup(vbox, "<b>Source files:</b>");
+	m_LongitudeDir = add_combo_box(vbox, "Positive longitude is:", LongitudeStrings, 
+		"Interpretation of positive values of longitude in source FITS files.");
+
 	// Testing and debugging
 	vbox = CreatePage(PAGE_DEBUGGING, "Testing and debugging", "debugging", TRUE);
 	m_DebugOutputs = add_check_button(vbox, "Print debug messages",
@@ -398,44 +452,47 @@ bool CPreferencesDlg::OnResponseDialog(gint response_id)
 
 void CPreferencesDlg::LoadConfig()
 {
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NegativeCharts), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NegativeCharts),
 		CConfig::GetBool(CConfig::NEGATIVE_CHARTS));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NoPreviews), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NoPreviews),
 		CConfig::GetBool(CConfig::DISABLE_PREVIEWS));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_SoundFinished), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_SoundFinished),
 		CConfig::GetBool(CConfig::EVENT_SOUNDS));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_DebugOutputs), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_DebugOutputs),
 		CConfig::GetBool(CConfig::DEBUG_OUTPUTS));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NoMaximize), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_NoMaximize),
 		CConfig::GetBool(CConfig::NO_MAXIMIZE));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_RowsUpward), 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_RowsUpward),
 		CConfig::GetBool(CConfig::ROWS_UPWARD));
+	gtk_combo_box_set_active(GTK_COMBO_BOX(m_LongitudeDir),
+		CConfig::GetBool(CConfig::POSITIVE_WEST) ? 1 : 0);
 
 	int cols = CConfig::GetInt(CConfig::FILE_LIST_COLUMNS);
-	for (GSList *ptr=m_Columns; ptr!=NULL; ptr=ptr->next) {
-		tColumnData *data = (tColumnData*)ptr->data;
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->btn), (cols & data->info->bitmask)!=0);
+	for (GSList* ptr = m_Columns; ptr != NULL; ptr = ptr->next) {
+		tColumnData* data = (tColumnData*)ptr->data;
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->btn), (cols & data->info->bitmask) != 0);
 	}
 
-	for (GSList *ptr=m_Catalogs; ptr!=NULL; ptr=ptr->next) {
-		tCatalogData *data = (tCatalogData*)ptr->data;
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->toggle), 
+	for (GSList* ptr = m_Catalogs; ptr != NULL; ptr = ptr->next) {
+		tCatalogData* data = (tCatalogData*)ptr->data;
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->toggle),
 			CConfig::GetBool((CConfig::tParameter)data->info->par_use));
-		gchar *text = CConfig::GetStr((CConfig::tParameter)data->info->par_path);
-		gtk_entry_set_text(GTK_ENTRY(data->entry), (text!=NULL ? text : ""));
+		gchar* text = CConfig::GetStr((CConfig::tParameter)data->info->par_path);
+		gtk_entry_set_text(GTK_ENTRY(data->entry), (text != NULL ? text : ""));
 		g_free(text);
 	}
 
-	for (GSList *ptr=m_Dirs; ptr!=NULL; ptr=ptr->next) {
-		tDirData *data = (tDirData*)ptr->data;
-		gchar *path = CConfig::GetStr((CConfig::tParameter)data->info->param_id);
-		if (path && path[0]!='\0') {
+	for (GSList* ptr = m_Dirs; ptr != NULL; ptr = ptr->next) {
+		tDirData* data = (tDirData*)ptr->data;
+		gchar* path = CConfig::GetStr((CConfig::tParameter)data->info->param_id);
+		if (path && path[0] != '\0') {
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->toggle), TRUE);
 			gtk_entry_set_text(GTK_ENTRY(data->entry), path);
-		} else {
+		}
+		else {
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->toggle), FALSE);
-			gchar *defpath = data->info->def_fn(data->info->param_id);
-			gtk_entry_set_text(GTK_ENTRY(data->entry), (defpath!=NULL ? defpath : ""));
+			gchar* defpath = data->info->def_fn(data->info->param_id);
+			gtk_entry_set_text(GTK_ENTRY(data->entry), (defpath != NULL ? defpath : ""));
 			g_free(defpath);
 		}
 		g_free(path);
@@ -456,6 +513,8 @@ void CPreferencesDlg::SaveConfig()
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_NoMaximize))!=0);
 	CConfig::SetBool(CConfig::ROWS_UPWARD,
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_RowsUpward))!=0);
+	CConfig::SetBool(CConfig::POSITIVE_WEST,
+		gtk_combo_box_get_active(GTK_COMBO_BOX(m_LongitudeDir)) != 0);
 
 	int cols = 0;
 	for (GSList *ptr=m_Columns; ptr!=NULL; ptr=ptr->next) {
@@ -555,6 +614,11 @@ void CPreferencesDlg::OnSetDefaultsClicked(GtkButton *pButton)
 			CConfig::GetDefaultBool(CConfig::DISABLE_PREVIEWS));
 		break;
 
+	case PAGE_PROJECT_DEFAULTS:
+		gtk_combo_box_set_active(GTK_COMBO_BOX(m_LongitudeDir),
+			CConfig::GetDefaultBool(CConfig::POSITIVE_WEST) ? 1 : 0);
+		break;
+
 	case PAGE_DEBUGGING:
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_DebugOutputs), 
 			CConfig::GetDefaultBool(CConfig::DEBUG_OUTPUTS));
