@@ -356,6 +356,8 @@ static GtkFileFilter *FileFilter(gint type)
 CExportHeaderDlg::CExportHeaderDlg(GtkWindow *pParent):m_pParent(pParent), 
 	m_FileType(TYPE_CSV), m_Matched(false), m_Updating(false)
 {
+	m_Options[0].header = false;
+
 	// Dialog with buttons
 	m_pDlg = gtk_file_chooser_dialog_new("Export header", pParent,
 		GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
@@ -482,7 +484,7 @@ gchar *CExportHeaderDlg::Execute(const gchar *name)
 	// File types
 	gtk_combo_box_set_model(GTK_COMBO_BOX(m_TypeCombo), NULL);
 	gtk_list_store_clear(m_FileTypes);
-	for (int i=0; FileFormats[i].Caption; i++) {
+	for (int i=0; FileFormats[i].Id != NULL; i++) {
 		GtkTreeIter iter;
 		gtk_list_store_append(m_FileTypes, &iter);
 		gtk_list_store_set(m_FileTypes, &iter, 0, i, 1, FileFormats[i].Caption, -1);
