@@ -71,9 +71,13 @@ static void str_add(String *str, char ch)
 {
 	if (str->count >= str->capacity) {
 		str->capacity += ALLOC_BY;
-		str->buf = (char*) realloc(str->buf, str->capacity*sizeof(char));
+		char* newptr = (char*)realloc(str->buf, str->capacity*sizeof(char));
+		if (!newptr)
+			free(str->buf);
+		str->buf = newptr;
 	}
-	str->buf[str->count++] = ch;
+	if (str->buf)
+		str->buf[str->count++] = ch;
 }
 
 /* Append a string to a buffer */
@@ -85,10 +89,15 @@ static void str_ncat(String *str, const char *buf, size_t len)
 				str->capacity = str->count + len;
 			else
 				str->capacity = str->capacity + ALLOC_BY;
-			str->buf = (char*) realloc(str->buf, str->capacity*sizeof(char));
+			char* newptr = (char*) realloc(str->buf, str->capacity*sizeof(char));
+			if (!newptr)
+				free(str->buf);
+			str->buf = newptr;
+		}
+		if (str->buf) {
+			memcpy(str->buf + str->count, buf, len * sizeof(char));
+			str->count += len;
 		}
-		memcpy(str->buf + str->count, buf, len*sizeof(char));
-		str->count += len;
 	}
 }	
 
