@@ -177,7 +177,10 @@ static int set_data(const char *str, CmdParamInstance *inst)
 			if (StrToKeyVal(str, &key, &val)) {
 				if (data->count+2>data->capacity) {
 					data->capacity += 16;
-					data->val.str_vec = (char**)realloc(data->val.str_vec, data->capacity * sizeof(char*));
+					char** newptr = (char**)realloc(data->val.str_vec, data->capacity * sizeof(char*)); 
+					if (!newptr)
+						free(data->val.str_vec);
+					data->val.str_vec = newptr;
 				}
 				if (data->val.str_vec) {
 					data->val.str_vec[data->count++] = key;
@@ -212,7 +215,10 @@ static int set_data(const char *str, CmdParamInstance *inst)
 			if (CheckFilePath(buf)) {
 				if (data->count>=data->capacity) {
 					data->capacity += 16;
-					data->val.str_vec = (char**)realloc(data->val.str_vec, data->capacity * sizeof(char*));
+					char** newptr = (char**)realloc(data->val.str_vec, data->capacity * sizeof(char*));
+					if (!newptr)
+						free(data->val.str_vec);
+					data->val.str_vec = newptr;
 				}
 				if (data->val.str_vec) {
 					data->val.str_vec[data->count++] = buf;
